/**
 * Copyright 2006-8 Simon Andrews
 *
 *    This file is part of FRETSaw.
 *
 *    FRETSaw is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FRETSaw is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ChIPMonk; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FretSaw.IO;

import ij.ImagePlus;

import java.io.File;
import java.io.IOException;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;

import uk.ac.bbsrc.babraham.FretSaw.FretSawApplication;
import uk.ac.bbsrc.babraham.FretSaw.Preferences.FretSawPreferences;

public class OIBLoader extends ImageLoader {

	private File file = null;
	
	public OIBLoader (FretSawApplication application) {
		super(application);
	}

	public ImageSet getImageSet() throws IOException {
		JFileChooser chooser = new JFileChooser(FretSawPreferences.getInstance().lastDirectory());
		chooser.setMultiSelectionEnabled(true);
		chooser.setFileFilter(new FileFilter() {
		
			public String getDescription() {
				return "Olympus Files";
			}
			public boolean accept(File f) {
				if (f.isDirectory() || f.getName().toLowerCase().endsWith(".oib")) {
					return true;
				}
				return false;
			}
		});
		
		
		int result = chooser.showOpenDialog(application);
		if (result == JFileChooser.CANCEL_OPTION) return null;

		File file = chooser.getSelectedFile();

		if (file == null) return null;
		
		this.file = file;
		
		ImagePlus [] channels = BioFormatsImageLoader.loadImages(file);
		if (channels.length != 2) {
			throw new IOException("Should have found 2 channels, but found "+channels.length);
		}

		return new ImageSet(channels[0],channels[1]);
		
	}

	@Override
	public String getFileName() {
		if (file != null) return file.getName();
		return "";
	}

	@Override
	public File getLastDirectory() {
		if (file != null) return file.getParentFile();
		return null;
	}

}
